@@ -1,6 +1,6 @@
 from random import random, choice
 
-from relic_engine import get_relic_list, get_set_data
+from relic_engine import build_json_files
 import itertools
 
 num_runs_dict = {
@@ -26,7 +26,6 @@ chance_dict = {
     0.02: 0.02
 }
 
-relic_list = get_relic_list()
 
 def get_set_name(item_name):
     if "Kavasa" not in item_name:
@@ -56,14 +55,12 @@ def get_ducats(item_name, set_data):
         return 0
 
 
-def get_drop_priority(relics, min_price=30, set_data=None):
+def get_drop_priority(relics, set_data, relic_data, min_price=30):
     plat_list = []
     ducat_list = []
-    if set_data is None:
-        set_data = get_set_data()
 
     for relic in relics:
-        for drop in relic_list[relic]['Intact']['drops']:
+        for drop in relic_data[relic]['Intact']['drops']:
             if get_set_price(drop, set_data) >= min_price:
                 plat_list.append([drop, get_price(drop, set_data)])
             else:
@@ -78,10 +75,10 @@ def get_drop_priority(relics, min_price=30, set_data=None):
     return drop_prioity
 
 
-def get_possible_rewards(relics, refinement):
+def get_possible_rewards(relics, refinement, relic_data):
     drops = []
     for relic in relics:
-        drops.append(relic_list[relic][refinement]['drops'])
+        drops.append(relic_data[relic][refinement]['drops'])
 
     return drops
 
@@ -150,18 +147,19 @@ def process_run(drops, offcycle_drops, style, drop_priority):
     return best_drop, reward_screen
 
 
-def simulate_relic(relics, offcycle_relics, refinement, offcycle_refinement, style, amount, drop_priority=None):
+def simulate_relic(relics, offcycle_relics, refinement, offcycle_refinement, style, amount, set_data, relic_data,
+                   drop_priority=None):
     reward_list = []
     reward_screen = []
     offcycle_drops = []
 
-    drops = get_possible_rewards(relics, refinement)
+    drops = get_possible_rewards(relics, refinement, relic_data)
 
     for i in range(len(offcycle_relics)):
-        offcycle_drops.append(get_possible_rewards(offcycle_relics[i], offcycle_refinement[i]))
+        offcycle_drops.append(get_possible_rewards(offcycle_relics[i], offcycle_refinement[i], relic_data))
 
     if drop_priority is None:
-        drop_priority = get_drop_priority(relics + [j for i in offcycle_relics for j in i])
+        drop_priority = get_drop_priority(relics + [j for i in offcycle_relics for j in i], set_data, relic_data)
 
     reward_list, reward_screen = zip(*[process_run(drops, offcycle_drops, style, drop_priority)
                                        for _ in itertools.repeat(None, int(amount * num_runs_dict[style]))])
